<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=fr_fem
// ** ne pas modifier le fichier **

return [

	// S
	'sites_description' => 'Sites et syndication dans SPIP (privé et public)',
	'sites_slogan' => 'Gestion des sites et de la syndication dans SPIP',
];
